---
title: <span class="badge object-type-scalar"></span> Watt
---
# <span class="badge object-type-scalar"></span> Watt

Energy: Watt (W)

## Definition

```python
# Energy: Watt (W)
Watt: typing.Literal["watt"] = "watt"
```
